.. MeldDict documentation master file, created by
   sphinx-quickstart on Tue Apr  3 12:44:32 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: readme.rst


.. toctree::
   :hidden:

   melddict

.. include:: melddict.rst

.. toctree::
   :glob:
   :maxdepth: 3

   changelog
